#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witch
version:              1.2.0.2
visibility:           public
id:                   witch-1.2.0.2-GqEc8hKkMUP6xQ3HMl9AY2
key:                  witch-1.2.0.2-GqEc8hKkMUP6xQ3HMl9AY2
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Convert values from one type into another.
description:          Witch converts values from one type into another.
category:             Data
abi:                  9124eba851333526a7cb44c3bb642231
exposed:              True
exposed-modules:
    Witch Witch.Encoding Witch.From Witch.Instances Witch.Lift
    Witch.TryFrom Witch.TryFromException Witch.Utility

import-dirs:          /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witch
hs-libraries:         HSwitch-1.2.0.2-GqEc8hKkMUP6xQ3HMl9AY2
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-witch/html/witch.haddock
haddock-html:         /usr/share/doc/haskell-witch/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

